@@ -2,25 +2,8 @@
  * pydisk.h
  * pyparted type objects for pydisk.c
  *
- * Copyright (C) 2007-2013 Red Hat, Inc.
- *
- * This copyrighted material is made available to anyone wishing to use,
- * modify, copy, or redistribute it subject to the terms and conditions of
- * the GNU General Public License v.2, or (at your option) any later version.
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY expressed or implied, including the implied warranties of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
- * Public License for more details.  You should have received a copy of the
- * GNU General Public License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.  Any Red Hat trademarks that are incorporated in the
- * source code or documentation are not subject to the GNU General Public
- * License and may only be used or replicated with the express permission of
- * Red Hat, Inc.
- *
- * Author(s): David Cantrell <dcantrell@redhat.com>
- *            Chris Lumens <clumens@redhat.com>
- *            Alex Skinner <alex@lx.lc>
+ * Copyright The pyparted Project Authors
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef TYPEOBJECTS_PYDISK_H_INCLUDED
@@ -29,6 +12,8 @@
 #include <Python.h>
 #include <structmember.h>
 
+#include <parted/parted.h>
+
 /* _ped.Partition type object */
 static PyMemberDef _ped_Partition_members[] = {
     {"disk", T_OBJECT, offsetof(_ped_Partition, disk), READONLY,
@@ -57,10 +42,24 @@ static PyMethodDef _ped_Partition_methods[] = {
                  partition_set_name_doc},
     {"get_name", (PyCFunction) py_ped_partition_get_name, METH_VARARGS,
                  partition_get_name_doc},
+#if PED_DISK_TYPE_LAST_FEATURE > 2
+    {"set_type_id", (PyCFunction) py_ped_partition_set_type_id, METH_VARARGS,
+                 partition_set_type_id_doc},
+    {"get_type_id", (PyCFunction) py_ped_partition_get_type_id, METH_VARARGS,
+                 partition_get_type_id_doc},
+#endif /* PED_DISK_TYPE_LAST_FEATURE > 2 */
+#if PED_DISK_TYPE_LAST_FEATURE > 4
+    {"set_type_uuid", (PyCFunction) py_ped_partition_set_type_uuid, METH_VARARGS,
+                 partition_set_type_uuid_doc},
+    {"get_type_uuid", (PyCFunction) py_ped_partition_get_type_uuid, METH_VARARGS,
+                 partition_get_type_uuid_doc},
+#endif /* PED_DISK_TYPE_LAST_FEATURE > 4 */
     {"is_busy", (PyCFunction) py_ped_partition_is_busy, METH_VARARGS,
                 partition_is_busy_doc},
     {"get_path", (PyCFunction) py_ped_partition_get_path, METH_VARARGS,
                  partition_get_path_doc},
+    {"reset_num", (PyCFunction) py_ped_partition_reset_num, METH_VARARGS,
+                  partition_reset_num_doc},
     {NULL}
 };
 
@@ -319,6 +318,3 @@ PyTypeObject _ped_DiskType_Type_obj = {
 };
 
 #endif /* TYPEOBJECTS_PYDISK_H_INCLUDED */
-
-/* vim:tw=78:ts=4:et:sw=4
- */
