@@ -4,25 +4,8 @@
  * need to be converted.  When a typedef in libparted is a primitive type,
  * we can just use it directly.
  *
- * Copyright (C) 2007-2013 Red Hat, Inc.
- *
- * This copyrighted material is made available to anyone wishing to use,
- * modify, copy, or redistribute it subject to the terms and conditions of
- * the GNU General Public License v.2, or (at your option) any later version.
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY expressed or implied, including the implied warranties of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
- * Public License for more details.  You should have received a copy of the
- * GNU General Public License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.  Any Red Hat trademarks that are incorporated in the
- * source code or documentation are not subject to the GNU General Public
- * License and may only be used or replicated with the express permission of
- * Red Hat, Inc.
- *
- * Author(s): David Cantrell <dcantrell@redhat.com>
- *            Chris Lumens <clumens@redhat.com>
- *            Alex Skinner <alex@lx.lc>
+ * Copyright The pyparted Project Authors
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include <Python.h>
@@ -67,7 +50,8 @@
  */
 
 /* _ped_Alignment -> PedAlignment functions */
-PedAlignment *_ped_Alignment2PedAlignment(PyObject *s) {
+PedAlignment *_ped_Alignment2PedAlignment(PyObject *s)
+{
     PedAlignment *ret = NULL;
     _ped_Alignment *alignment = (_ped_Alignment *) s;
 
@@ -77,13 +61,16 @@ PedAlignment *_ped_Alignment2PedAlignment(PyObject *s) {
     }
 
     ret = ped_alignment_new(alignment->offset, alignment->grain_size);
-    if (ret == NULL)
+
+    if (ret == NULL) {
         return (PedAlignment *) PyErr_NoMemory();
+    }
 
     return ret;
 }
 
-_ped_Alignment *PedAlignment2_ped_Alignment(PedAlignment *alignment) {
+_ped_Alignment *PedAlignment2_ped_Alignment(PedAlignment *alignment)
+{
     _ped_Alignment *ret = NULL;
     PyObject *args = NULL;
 
@@ -93,10 +80,13 @@ _ped_Alignment *PedAlignment2_ped_Alignment(PedAlignment *alignment) {
     }
 
     ret = (_ped_Alignment *) _ped_Alignment_Type_obj.tp_new(&_ped_Alignment_Type_obj, NULL, NULL);
-    if (!ret)
+
+    if (!ret) {
         return (_ped_Alignment *) PyErr_NoMemory();
+    }
 
     args = Py_BuildValue("LL", alignment->offset, alignment->grain_size);
+
     if (args == NULL) {
         goto error;
     }
@@ -106,7 +96,6 @@ _ped_Alignment *PedAlignment2_ped_Alignment(PedAlignment *alignment) {
     }
 
     Py_DECREF(args);
-
     return ret;
 
 error:
@@ -116,7 +105,8 @@ error:
 }
 
 /* _ped_Constraint -> PedConstraint functions */
-PedConstraint *_ped_Constraint2PedConstraint(PyObject *s) {
+PedConstraint *_ped_Constraint2PedConstraint(PyObject *s)
+{
     PedConstraint *ret = NULL;
     PedAlignment *start_align = NULL, *end_align = NULL;
     PedGeometry *start_range = NULL, *end_range = NULL;
@@ -128,17 +118,20 @@ PedConstraint *_ped_Constraint2PedConstraint(PyObject *s) {
     }
 
     start_align = _ped_Alignment2PedAlignment(constraint->start_align);
+
     if (start_align == NULL) {
         return NULL;
     }
 
     end_align = _ped_Alignment2PedAlignment(constraint->end_align);
+
     if (end_align == NULL) {
         ped_alignment_destroy(start_align);
         return NULL;
     }
 
     start_range = _ped_Geometry2PedGeometry(constraint->start_range);
+
     if (start_range == NULL) {
         ped_alignment_destroy(start_align);
         ped_alignment_destroy(end_align);
@@ -146,14 +139,15 @@ PedConstraint *_ped_Constraint2PedConstraint(PyObject *s) {
     }
 
     end_range = _ped_Geometry2PedGeometry(constraint->end_range);
+
     if (end_range == NULL) {
         ped_alignment_destroy(start_align);
         ped_alignment_destroy(end_align);
         return NULL;
     }
 
-    ret = ped_constraint_new(start_align, end_align, start_range, end_range,
-                             constraint->min_size, constraint->max_size);
+    ret = ped_constraint_new(start_align, end_align, start_range, end_range, constraint->min_size, constraint->max_size);
+
     if (ret == NULL) {
         /* Fall through to clean up memory, but set the error condition now. */
         PyErr_NoMemory();
@@ -161,11 +155,11 @@ PedConstraint *_ped_Constraint2PedConstraint(PyObject *s) {
 
     ped_alignment_destroy(start_align);
     ped_alignment_destroy(end_align);
-
     return ret;
 }
 
-_ped_Constraint *PedConstraint2_ped_Constraint(PedConstraint *constraint) {
+_ped_Constraint *PedConstraint2_ped_Constraint(PedConstraint *constraint)
+{
     _ped_Constraint *ret = NULL;
     _ped_Alignment *start_align = NULL;
     _ped_Alignment *end_align = NULL;
@@ -179,22 +173,37 @@ _ped_Constraint *PedConstraint2_ped_Constraint(PedConstraint *constraint) {
     }
 
     ret = (_ped_Constraint *) _ped_Constraint_Type_obj.tp_new(&_ped_Constraint_Type_obj, NULL, NULL);
-    if (!ret)
+
+    if (!ret) {
         return (_ped_Constraint *) PyErr_NoMemory();
+    }
 
-    if ((start_align = PedAlignment2_ped_Alignment(constraint->start_align)) == NULL)
-        goto error;
+    start_align = PedAlignment2_ped_Alignment(constraint->start_align);
 
-    if ((end_align = PedAlignment2_ped_Alignment(constraint->end_align)) == NULL)
+    if (!start_align) {
         goto error;
+    }
 
-    if ((start_range = PedGeometry2_ped_Geometry(constraint->start_range)) == NULL)
-        goto error;
+    end_align = PedAlignment2_ped_Alignment(constraint->end_align);
 
-    if ((end_range = PedGeometry2_ped_Geometry(constraint->end_range)) == NULL)
+    if (!end_align) {
         goto error;
+    }
+
+    start_range = PedGeometry2_ped_Geometry(constraint->start_range);
+
+    if (!start_range) {
+        goto error;
+    }
+
+    end_range = PedGeometry2_ped_Geometry(constraint->end_range);
+
+    if (!end_range) {
+        goto error;
+    }
 
     args = Py_BuildValue("OOOOLL", start_align, end_align, start_range, end_range, constraint->min_size, constraint->max_size);
+
     if (args == NULL) {
         goto error;
     }
@@ -208,7 +217,6 @@ _ped_Constraint *PedConstraint2_ped_Constraint(PedConstraint *constraint) {
     Py_DECREF(end_align);
     Py_DECREF(start_range);
     Py_DECREF(end_range);
-
     return ret;
 
 error:
@@ -222,7 +230,8 @@ error:
 }
 
 /* _ped_Device -> PedDevice functions */
-PedDevice *_ped_Device2PedDevice(PyObject *s) {
+PedDevice *_ped_Device2PedDevice(PyObject *s)
+{
     _ped_Device *dev = (_ped_Device *) s;
     PedDevice *ret;
 
@@ -232,22 +241,25 @@ PedDevice *_ped_Device2PedDevice(PyObject *s) {
     }
 
     ret = ped_device_get(dev->path);
+
     if (ret == NULL) {
         if (partedExnRaised) {
             partedExnRaised = 0;
 
-            if (!PyErr_ExceptionMatches(PartedException) &&
-                !PyErr_ExceptionMatches(PyExc_NotImplementedError))
+            if (!PyErr_ExceptionMatches(PartedException) && !PyErr_ExceptionMatches(PyExc_NotImplementedError)) {
                 PyErr_SetString(DeviceException, partedExnMessage);
-        }
-        else
+            }
+        } else {
             PyErr_Format(DeviceException, "Could not find device for path %s", dev->path);
+        }
     }
+
     return ret;
 }
 
 /* PedDevice -> _ped_Device functions */
-_ped_Device *PedDevice2_ped_Device(PedDevice *device) {
+_ped_Device *PedDevice2_ped_Device(PedDevice *device)
+{
     _ped_Device *ret = NULL;
 
     if (device == NULL) {
@@ -256,16 +268,20 @@ _ped_Device *PedDevice2_ped_Device(PedDevice *device) {
     }
 
     ret = (_ped_Device *) _ped_Device_Type_obj.tp_alloc(&_ped_Device_Type_obj, 1);
-    if (!ret)
+
+    if (!ret) {
         return (_ped_Device *) PyErr_NoMemory();
+    }
 
     ret->model = strdup(device->model);
+
     if (ret->model == NULL) {
         PyErr_NoMemory();
         goto error;
     }
 
     ret->path = strdup(device->path);
+
     if (ret->path == NULL) {
         PyErr_NoMemory();
         goto error;
@@ -284,12 +300,16 @@ _ped_Device *PedDevice2_ped_Device(PedDevice *device) {
     ret->length = device->length;
 
     ret->hw_geom = (PyObject *) PedCHSGeometry2_ped_CHSGeometry(&device->hw_geom);
-    if (ret->hw_geom == NULL)
+
+    if (ret->hw_geom == NULL) {
         goto error;
+    }
 
     ret->bios_geom = (PyObject *) PedCHSGeometry2_ped_CHSGeometry(&device->bios_geom);
-    if (ret->bios_geom == NULL)
+
+    if (ret->bios_geom == NULL) {
         goto error;
+    }
 
     return ret;
 
@@ -298,7 +318,8 @@ error:
     return NULL;
 }
 
-PedDisk *_ped_Disk2PedDisk(PyObject *s) {
+PedDisk *_ped_Disk2PedDisk(PyObject *s)
+{
     _ped_Disk *disk = (_ped_Disk *) s;
 
     if (disk == NULL) {
@@ -309,7 +330,8 @@ PedDisk *_ped_Disk2PedDisk(PyObject *s) {
     return disk->ped_disk;
 }
 
-_ped_Disk *PedDisk2_ped_Disk(PedDisk *disk) {
+_ped_Disk *PedDisk2_ped_Disk(PedDisk *disk)
+{
     _ped_Disk *ret = NULL;
 
     if (disk == NULL) {
@@ -318,19 +340,24 @@ _ped_Disk *PedDisk2_ped_Disk(PedDisk *disk) {
     }
 
     ret = (_ped_Disk *) _ped_Disk_Type_obj.tp_new(&_ped_Disk_Type_obj, NULL, NULL);
+
     if (!ret) {
         ped_disk_destroy(disk);
         return (_ped_Disk *) PyErr_NoMemory();
     }
-    ret->ped_disk = disk;
 
+    ret->ped_disk = disk;
     ret->dev = (PyObject *) PedDevice2_ped_Device(disk->dev);
-    if (!ret->dev)
+
+    if (!ret->dev) {
         goto error;
+    }
 
     ret->type = (PyObject *) PedDiskType2_ped_DiskType(disk->type);
-    if (!ret->type)
+
+    if (!ret->type) {
         goto error;
+    }
 
     return ret;
 
@@ -339,7 +366,8 @@ error:
     return NULL;
 }
 
-PedDiskType *_ped_DiskType2PedDiskType(PyObject *s) {
+PedDiskType *_ped_DiskType2PedDiskType(PyObject *s)
+{
     PedDiskType *ret = NULL;
     _ped_DiskType *type = (_ped_DiskType *) s;
 
@@ -349,6 +377,7 @@ PedDiskType *_ped_DiskType2PedDiskType(PyObject *s) {
     }
 
     ret = ped_disk_type_get(type->name);
+
     if (ret == NULL) {
         PyErr_SetString(UnknownTypeException, type->name);
         return NULL;
@@ -357,7 +386,8 @@ PedDiskType *_ped_DiskType2PedDiskType(PyObject *s) {
     return ret;
 }
 
-_ped_DiskType *PedDiskType2_ped_DiskType(const PedDiskType *type) {
+_ped_DiskType *PedDiskType2_ped_DiskType(const PedDiskType *type)
+{
     _ped_DiskType *ret = NULL;
 
     if (type == NULL) {
@@ -366,22 +396,25 @@ _ped_DiskType *PedDiskType2_ped_DiskType(const PedDiskType *type) {
     }
 
     ret = (_ped_DiskType *) _ped_DiskType_Type_obj.tp_alloc(&_ped_DiskType_Type_obj, 1);
-    if (!ret)
+
+    if (!ret) {
         return (_ped_DiskType *) PyErr_NoMemory();
+    }
 
     ret->name = strdup(type->name);
+
     if (ret->name == NULL) {
         Py_DECREF(ret);
         return (_ped_DiskType *) PyErr_NoMemory();
     }
 
     ret->features = type->features;
-
     return ret;
 }
 
 /* _ped_FileSystem -> PedFileSystem functions */
-PedFileSystem *_ped_FileSystem2PedFileSystem(PyObject *s) {
+PedFileSystem *_ped_FileSystem2PedFileSystem(PyObject *s)
+{
     _ped_FileSystem *fs = (_ped_FileSystem *) s;
 
     if (fs == NULL) {
@@ -397,7 +430,8 @@ PedFileSystem *_ped_FileSystem2PedFileSystem(PyObject *s) {
     }
 }
 
-_ped_FileSystem *PedFileSystem2_ped_FileSystem(PedFileSystem *fs) {
+_ped_FileSystem *PedFileSystem2_ped_FileSystem(PedFileSystem *fs)
+{
     _ped_FileSystem *ret = NULL;
     _ped_FileSystemType *type = NULL;
     _ped_Geometry *geom = NULL;
@@ -409,16 +443,25 @@ _ped_FileSystem *PedFileSystem2_ped_FileSystem(PedFileSystem *fs) {
     }
 
     ret = (_ped_FileSystem *) _ped_FileSystem_Type_obj.tp_new(&_ped_FileSystem_Type_obj, NULL, NULL);
-    if (!ret)
+
+    if (!ret) {
         return (_ped_FileSystem *) PyErr_NoMemory();
+    }
 
-    if ((type = PedFileSystemType2_ped_FileSystemType(fs->type)) == NULL)
-        goto error;
+    type = PedFileSystemType2_ped_FileSystemType(fs->type);
 
-    if ((geom = PedGeometry2_ped_Geometry(fs->geom)) == NULL)
+    if (!type) {
         goto error;
+    }
+
+    geom = PedGeometry2_ped_Geometry(fs->geom);
+
+    if (!geom) {
+        goto error;
+    }
 
     args = Py_BuildValue("OOi", type, geom, fs->checked);
+
     if (args == NULL) {
         goto error;
     }
@@ -430,7 +473,6 @@ _ped_FileSystem *PedFileSystem2_ped_FileSystem(PedFileSystem *fs) {
     Py_DECREF(args);
     Py_DECREF(type);
     Py_DECREF(geom);
-
     return ret;
 
 error:
@@ -442,7 +484,8 @@ error:
 }
 
 /* _ped_FileSystemType -> PedFileSystemType functions */
-PedFileSystemType *_ped_FileSystemType2PedFileSystemType(PyObject *s) {
+PedFileSystemType *_ped_FileSystemType2PedFileSystemType(PyObject *s)
+{
     PedFileSystemType *ret = NULL;
     _ped_FileSystemType *type = (_ped_FileSystemType *) s;
 
@@ -451,7 +494,9 @@ PedFileSystemType *_ped_FileSystemType2PedFileSystemType(PyObject *s) {
         return NULL;
     }
 
-    if ((ret = ped_file_system_type_get(type->name)) == NULL) {
+    ret = ped_file_system_type_get(type->name);
+
+    if (!ret) {
         PyErr_SetString(UnknownTypeException, type->name);
         return NULL;
     }
@@ -459,7 +504,8 @@ PedFileSystemType *_ped_FileSystemType2PedFileSystemType(PyObject *s) {
     return ret;
 }
 
-_ped_FileSystemType *PedFileSystemType2_ped_FileSystemType(const PedFileSystemType *fstype) {
+_ped_FileSystemType *PedFileSystemType2_ped_FileSystemType(const PedFileSystemType *fstype)
+{
     _ped_FileSystemType *ret = NULL;
 
     if (fstype == NULL) {
@@ -468,10 +514,13 @@ _ped_FileSystemType *PedFileSystemType2_ped_FileSystemType(const PedFileSystemTy
     }
 
     ret = (_ped_FileSystemType *) _ped_FileSystemType_Type_obj.tp_alloc(&_ped_FileSystemType_Type_obj, 1);
-    if (!ret)
+
+    if (!ret) {
        return (_ped_FileSystemType *) PyErr_NoMemory();
+    }
 
     ret->name = strdup(fstype->name);
+
     if (ret->name == NULL) {
         Py_DECREF(ret);
         return (_ped_FileSystemType *) PyErr_NoMemory();
@@ -481,7 +530,8 @@ _ped_FileSystemType *PedFileSystemType2_ped_FileSystemType(const PedFileSystemTy
 }
 
 /* _ped_Geometry -> PedGeometry functions */
-PedGeometry *_ped_Geometry2PedGeometry(PyObject *s) {
+PedGeometry *_ped_Geometry2PedGeometry(PyObject *s)
+{
     _ped_Geometry *geometry = (_ped_Geometry *) s;
 
     if (geometry == NULL) {
@@ -492,7 +542,8 @@ PedGeometry *_ped_Geometry2PedGeometry(PyObject *s) {
     return geometry->ped_geometry;
 }
 
-_ped_Geometry *PedGeometry2_ped_Geometry(PedGeometry *geometry) {
+_ped_Geometry *PedGeometry2_ped_Geometry(PedGeometry *geometry)
+{
     _ped_Geometry *ret = NULL;
     _ped_Device *dev = NULL;
     PyObject *args = NULL;
@@ -503,14 +554,20 @@ _ped_Geometry *PedGeometry2_ped_Geometry(PedGeometry *geometry) {
     }
 
     ret = (_ped_Geometry *) _ped_Geometry_Type_obj.tp_new(&_ped_Geometry_Type_obj, NULL, NULL);
-    if (!ret)
-        return (_ped_Geometry *) PyErr_NoMemory();
 
-    if ((dev = PedDevice2_ped_Device(geometry->dev)) == NULL)
+    if (!ret) {
+        return (_ped_Geometry *) PyErr_NoMemory();
+    }
+
+    dev = PedDevice2_ped_Device(geometry->dev);
+
+    if (!dev) {
         goto error;
+    }
 
     args = Py_BuildValue("OLLL", dev, geometry->start, geometry->length, geometry->end);
-    if (args == NULL) {
+
+    if (!args) {
         goto error;
     }
 
@@ -520,7 +577,6 @@ _ped_Geometry *PedGeometry2_ped_Geometry(PedGeometry *geometry) {
 
     Py_DECREF(args);
     Py_DECREF(dev);
-
     return ret;
 
 error:
@@ -531,7 +587,8 @@ error:
 }
 
 /* _ped_CHSGeometry -> PedCHSGeometry functions */
-PedCHSGeometry *_ped_CHSGeometry2PedCHSGeometry(PyObject *s) {
+PedCHSGeometry *_ped_CHSGeometry2PedCHSGeometry(PyObject *s)
+{
     PedCHSGeometry *ret = NULL;
     _ped_CHSGeometry *srcgeom = (_ped_CHSGeometry *) s;
 
@@ -540,8 +597,11 @@ PedCHSGeometry *_ped_CHSGeometry2PedCHSGeometry(PyObject *s) {
         return NULL;
     }
 
-    if ((ret = malloc(sizeof(PedCHSGeometry))) == NULL)
+    ret = malloc(sizeof(PedCHSGeometry));
+
+    if (!ret) {
         return (PedCHSGeometry *) PyErr_NoMemory();
+    }
 
     ret->cylinders = srcgeom->cylinders;
     ret->heads = srcgeom->heads;
@@ -551,7 +611,8 @@ PedCHSGeometry *_ped_CHSGeometry2PedCHSGeometry(PyObject *s) {
 }
 
 /* PedCHSGeometry -> _ped_CHSGeometry functions */
-_ped_CHSGeometry *PedCHSGeometry2_ped_CHSGeometry(PedCHSGeometry *geom) {
+_ped_CHSGeometry *PedCHSGeometry2_ped_CHSGeometry(PedCHSGeometry *geom)
+{
     _ped_CHSGeometry *ret = NULL;
 
     if (geom == NULL) {
@@ -560,17 +621,19 @@ _ped_CHSGeometry *PedCHSGeometry2_ped_CHSGeometry(PedCHSGeometry *geom) {
     }
 
     ret = (_ped_CHSGeometry *) _ped_CHSGeometry_Type_obj.tp_alloc(&_ped_CHSGeometry_Type_obj, 1);
-    if (!ret)
+
+    if (!ret) {
         return (_ped_CHSGeometry *) PyErr_NoMemory();
+    }
 
     ret->cylinders = geom->cylinders;
     ret->heads = geom->heads;
     ret->sectors = geom->sectors;
-
     return ret;
 }
 
-PedPartition *_ped_Partition2PedPartition(_ped_Partition *s) {
+PedPartition *_ped_Partition2PedPartition(_ped_Partition *s)
+{
     if (s == NULL) {
         PyErr_SetString(PyExc_TypeError, "Empty _ped.Partition()");
         return NULL;
@@ -579,8 +642,8 @@ PedPartition *_ped_Partition2PedPartition(_ped_Partition *s) {
     return s->ped_partition;
 }
 
-_ped_Partition *PedPartition2_ped_Partition(PedPartition *part,
-                                            _ped_Disk *pydisk) {
+_ped_Partition *PedPartition2_ped_Partition(PedPartition *part, _ped_Disk *pydisk)
+{
     _ped_Partition *ret = NULL;
 
     if (part == NULL) {
@@ -594,28 +657,32 @@ _ped_Partition *PedPartition2_ped_Partition(PedPartition *part,
     }
 
     ret = (_ped_Partition *) _ped_Partition_Type_obj.tp_new(&_ped_Partition_Type_obj, NULL, NULL);
-    if (!ret)
+
+    if (!ret) {
         return (_ped_Partition *) PyErr_NoMemory();
+    }
 
     ret->disk = (PyObject *)pydisk;
     Py_INCREF(ret->disk);
-
     ret->geom = (PyObject *)PedGeometry2_ped_Geometry(&part->geom);
-    if (!ret->geom)
+
+    if (!ret->geom) {
         goto error;
+    }
 
     if (part->fs_type == NULL) {
         ret->fs_type = Py_None;
         Py_INCREF(ret->fs_type);
     } else {
         ret->fs_type = (PyObject *)PedFileSystemType2_ped_FileSystemType(part->fs_type);
-        if (!ret->fs_type)
+
+        if (!ret->fs_type) {
             goto error;
+        }
     }
 
     ret->type = part->type;
     ret->ped_partition = part;
-
     return ret;
 
 error:
@@ -624,7 +691,8 @@ error:
 }
 
 /* _ped_Timer -> PedTimer functions */
-PedTimer *_ped_Timer2PedTimer(PyObject *s) {
+PedTimer *_ped_Timer2PedTimer(PyObject *s)
+{
     PedTimer *ret = NULL;
     _ped_Timer *timer = (_ped_Timer *) s;
 
@@ -633,8 +701,11 @@ PedTimer *_ped_Timer2PedTimer(PyObject *s) {
         return NULL;
     }
 
-    if ((ret = malloc(sizeof(PedTimer))) == NULL)
+    ret = malloc(sizeof(PedTimer));
+
+    if (!ret) {
         return (PedTimer *) PyErr_NoMemory();
+    }
 
     ret->frac = timer->frac;
     ret->start = timer->start;
@@ -642,8 +713,8 @@ PedTimer *_ped_Timer2PedTimer(PyObject *s) {
     ret->predicted_end = timer->predicted_end;
     ret->handler = timer->handler;
     ret->context = timer->context;
-
     ret->state_name = strdup(timer->state_name);
+
     if (ret->state_name == NULL) {
         free(ret);
         return (PedTimer *) PyErr_NoMemory();
@@ -653,7 +724,8 @@ PedTimer *_ped_Timer2PedTimer(PyObject *s) {
 }
 
 /* PedTimer -> _ped_Timer functions */
-_ped_Timer *PedTimer2_ped_Timer(PedTimer *timer) {
+_ped_Timer *PedTimer2_ped_Timer(PedTimer *timer)
+{
     _ped_Timer *ret = NULL;
 
     if (timer == NULL) {
@@ -662,16 +734,18 @@ _ped_Timer *PedTimer2_ped_Timer(PedTimer *timer) {
     }
 
     ret = (_ped_Timer *) _ped_Timer_Type_obj.tp_new(&_ped_Timer_Type_obj, NULL, NULL);
-    if (!ret)
+
+    if (!ret) {
         return (_ped_Timer *) PyErr_NoMemory();
+    }
 
     ret->frac = timer->frac;
     ret->start = timer->start;
     ret->now = timer->now;
     ret->predicted_end = timer->predicted_end;
-
     ret->state_name = strdup(timer->state_name);
-    if (ret->state_name == NULL) {
+
+    if (!ret->state_name) {
         Py_DECREF(ret);
         return (_ped_Timer *) PyErr_NoMemory();
     }
@@ -682,6 +756,3 @@ _ped_Timer *PedTimer2_ped_Timer(PedTimer *timer) {
 
     return ret;
 }
-
-/* vim:tw=78:ts=4:et:sw=4
- */
