@@ -1,25 +1,8 @@
 /*
  * pyconstraint.c
  *
- * Copyright (C) 2007-2013  Red Hat, Inc.
- *
- * This copyrighted material is made available to anyone wishing to use,
- * modify, copy, or redistribute it subject to the terms and conditions of
- * the GNU General Public License v.2, or (at your option) any later version.
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY expressed or implied, including the implied warranties of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
- * Public License for more details.  You should have received a copy of the
- * GNU General Public License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.  Any Red Hat trademarks that are incorporated in the
- * source code or documentation are not subject to the GNU General Public
- * License and may only be used or replicated with the express permission of
- * Red Hat, Inc.
- *
- * Author(s): David Cantrell <dcantrell@redhat.com>
- *            Chris Lumens <clumens@redhat.com>
- *            Alex Skinner <alex@lx.lc>
+ * Copyright The pyparted Project Authors
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include <Python.h>
@@ -33,7 +16,8 @@
 #include "typeobjects/pyconstraint.h"
 
 /* _ped.Constraint functions */
-void _ped_Constraint_dealloc(_ped_Constraint *self) {
+void _ped_Constraint_dealloc(_ped_Constraint *self)
+{
     PyObject_GC_UnTrack(self);
 
     Py_CLEAR(self->start_align);
@@ -51,7 +35,8 @@ void _ped_Constraint_dealloc(_ped_Constraint *self) {
     PyObject_GC_Del(self);
 }
 
-int _ped_Constraint_compare(_ped_Constraint *self, PyObject *obj) {
+int _ped_Constraint_compare(_ped_Constraint *self, PyObject *obj)
+{
     _ped_Constraint *comp = NULL;
     int check = PyObject_IsInstance(obj, (PyObject *) &_ped_Constraint_Type_obj);
 
@@ -65,26 +50,31 @@ int _ped_Constraint_compare(_ped_Constraint *self, PyObject *obj) {
     }
 
     comp = (_ped_Constraint *) obj;
-    if ((_ped_Alignment_Type_obj.tp_richcompare(self->start_align, comp->start_align, Py_EQ)) &&
-        (_ped_Alignment_Type_obj.tp_richcompare(self->end_align, comp->end_align, Py_EQ)) &&
-        (_ped_Geometry_Type_obj.tp_richcompare(self->start_range, comp->start_range, Py_EQ)) &&
-        (_ped_Geometry_Type_obj.tp_richcompare(self->end_range, comp->end_range, Py_EQ)) &&
-        (self->min_size == comp->min_size) &&
-        (self->max_size == comp->max_size)) {
+
+    if ((_ped_Alignment_Type_obj.tp_richcompare(self->start_align, comp->start_align, Py_EQ))
+        && (_ped_Alignment_Type_obj.tp_richcompare(self->end_align, comp->end_align, Py_EQ))
+        && (_ped_Geometry_Type_obj.tp_richcompare(self->start_range, comp->start_range, Py_EQ))
+        && (_ped_Geometry_Type_obj.tp_richcompare(self->end_range, comp->end_range, Py_EQ))
+        && (self->min_size == comp->min_size) && (self->max_size == comp->max_size)) {
         return 0;
     } else {
         return 1;
     }
 }
 
-PyObject *_ped_Constraint_richcompare(_ped_Constraint *a, PyObject *b, int op) {
+PyObject *_ped_Constraint_richcompare(_ped_Constraint *a, PyObject *b, int op)
+{
+    int rv;
+
     if (op == Py_EQ || op == Py_NE) {
-        int rv = _ped_Constraint_compare(a, b);
-        if (PyErr_Occurred())
+        rv = _ped_Constraint_compare(a, b);
+
+        if (PyErr_Occurred()) {
             return NULL;
+        }
+
         return PyBool_FromLong(op == Py_EQ ? rv == 0 : rv != 0);
-    } else if ((op == Py_LT) || (op == Py_LE) ||
-               (op == Py_GT) || (op == Py_GE)) {
+    } else if ((op == Py_LT) || (op == Py_LE) || (op == Py_GT) || (op == Py_GE)) {
         PyErr_SetString(PyExc_TypeError, "comparison operator not supported for _ped.Constraint");
         return NULL;
     } else {
@@ -93,32 +83,38 @@ PyObject *_ped_Constraint_richcompare(_ped_Constraint *a, PyObject *b, int op) {
     }
 }
 
-PyObject *_ped_Constraint_str(_ped_Constraint *self) {
-    char *ret = NULL;
+PyObject *_ped_Constraint_str(_ped_Constraint *self)
+{
+    PyObject *ret = NULL;
+    char *buf = NULL;
     char *start_align = NULL, *end_align = NULL;
     char *start_range = NULL, *end_range = NULL;
 
     start_align = (char *) PyUnicode_AsUTF8(_ped_Alignment_Type_obj.tp_repr(self->start_align));
+
     if (start_align == NULL) {
         return NULL;
     }
 
     end_align = (char *) PyUnicode_AsUTF8(_ped_Alignment_Type_obj.tp_repr(self->end_align));
+
     if (end_align == NULL) {
         return NULL;
     }
 
     start_range = (char *) PyUnicode_AsUTF8(_ped_Geometry_Type_obj.tp_repr(self->start_range));
+
     if (start_range == NULL) {
         return NULL;
     }
 
     end_range = (char *) PyUnicode_AsUTF8(_ped_Geometry_Type_obj.tp_repr(self->end_range));
+
     if (end_range == NULL) {
         return NULL;
     }
 
-    if (asprintf(&ret, "_ped.Constraint instance --\n"
+    if (asprintf(&buf, "_ped.Constraint instance --\n"
                        "  start_align: %s  end_align: %s\n"
                        "  start_range: %s  end_range: %s\n"
                        "  min_size: %lld  max_size: %lld",
@@ -128,40 +124,23 @@ PyObject *_ped_Constraint_str(_ped_Constraint *self) {
         return PyErr_NoMemory();
     }
 
-    return Py_BuildValue("s", ret);
+    ret = Py_BuildValue("s", buf);
+    free(buf);
+    return ret;
 }
 
-int _ped_Constraint_traverse(_ped_Constraint *self, visitproc visit, void *arg) {
-    int err;
-
-    if (self->start_align) {
-        if ((err = visit(self->start_align, arg))) {
-            return err;
-        }
-    }
-
-    if (self->end_align) {
-        if ((err = visit(self->end_align, arg))) {
-            return err;
-        }
-    }
-
-    if (self->start_range) {
-        if ((err = visit(self->start_range, arg))) {
-            return err;
-        }
-    }
-
-    if (self->end_range) {
-        if ((err = visit(self->end_range, arg))) {
-            return err;
-        }
-    }
+int _ped_Constraint_traverse(_ped_Constraint *self, visitproc visit, void *arg)
+{
+    Py_VISIT(self->start_align);
+    Py_VISIT(self->end_align);
+    Py_VISIT(self->start_range);
+    Py_VISIT(self->end_range);
 
     return 0;
 }
 
-int _ped_Constraint_clear(_ped_Constraint *self) {
+int _ped_Constraint_clear(_ped_Constraint *self)
+{
     Py_CLEAR(self->start_align);
     self->start_align = NULL;
 
@@ -177,10 +156,9 @@ int _ped_Constraint_clear(_ped_Constraint *self) {
     return 0;
 }
 
-int _ped_Constraint_init(_ped_Constraint *self, PyObject *args,
-                         PyObject *kwds) {
-    static char *kwlist[] = {"start_align", "end_align", "start_range",
-                             "end_range", "min_size", "max_size", NULL};
+int _ped_Constraint_init(_ped_Constraint *self, PyObject *args, PyObject *kwds)
+{
+    static char *kwlist[] = {"start_align", "end_align", "start_range", "end_range", "min_size", "max_size", NULL};
     PedConstraint *constraint = NULL;
     PedAlignment *start_align = NULL, *end_align = NULL;
     PedGeometry *start_range = NULL, *end_range = NULL;
@@ -223,12 +201,10 @@ int _ped_Constraint_init(_ped_Constraint *self, PyObject *args,
     start_range = _ped_Geometry2PedGeometry(self->start_range);
     end_range = _ped_Geometry2PedGeometry(self->end_range);
 
-    constraint = ped_constraint_new(start_align, end_align,
-                                    start_range, end_range,
-                                    self->min_size, self->max_size);
+    constraint = ped_constraint_new(start_align, end_align, start_range, end_range, self->min_size, self->max_size);
+
     if (constraint == NULL) {
         PyErr_SetString(CreateException, "Could not create new constraint");
-
         ped_alignment_destroy(start_align);
         ped_alignment_destroy(end_align);
         self->start_align = NULL;
@@ -251,7 +227,8 @@ int _ped_Constraint_init(_ped_Constraint *self, PyObject *args,
     return 0;
 }
 
-PyObject *_ped_Constraint_get(_ped_Constraint *self, void *closure) {
+PyObject *_ped_Constraint_get(_ped_Constraint *self, void *closure)
+{
     char *member = (char *) closure;
 
     if (member == NULL) {
@@ -269,7 +246,8 @@ PyObject *_ped_Constraint_get(_ped_Constraint *self, void *closure) {
     }
 }
 
-int _ped_Constraint_set(_ped_Constraint *self, PyObject *value, void *closure) {
+int _ped_Constraint_set(_ped_Constraint *self, PyObject *value, void *closure)
+{
     char *member = (char *) closure;
 
     if (member == NULL) {
@@ -279,11 +257,13 @@ int _ped_Constraint_set(_ped_Constraint *self, PyObject *value, void *closure) {
 
     if (!strcmp(member, "min_size")) {
         self->min_size = PyLong_AsLongLong(value);
+
         if (PyErr_Occurred()) {
             return -1;
         }
     } else if (!strcmp(member, "max_size")) {
         self->max_size = PyLong_AsLongLong(value);
+
         if (PyErr_Occurred()) {
             return -1;
         }
@@ -296,23 +276,25 @@ int _ped_Constraint_set(_ped_Constraint *self, PyObject *value, void *closure) {
 }
 
 /* 1:1 function mappings for constraint.h in libparted */
-PyObject *py_ped_constraint_new_from_min_max(PyObject *s, PyObject *args) {
+PyObject *py_ped_constraint_new_from_min_max(PyObject *s, PyObject *args)
+{
     PyObject *in_min = NULL, *in_max = NULL;
     PedGeometry *out_min = NULL, *out_max = NULL;
     PedConstraint *constraint = NULL;
     _ped_Constraint *ret = NULL;
 
-    if (!PyArg_ParseTuple(args, "O!O!", &_ped_Geometry_Type_obj, &in_min,
-                          &_ped_Geometry_Type_obj, &in_max)) {
+    if (!PyArg_ParseTuple(args, "O!O!", &_ped_Geometry_Type_obj, &in_min, &_ped_Geometry_Type_obj, &in_max)) {
         return NULL;
     }
 
     out_min = _ped_Geometry2PedGeometry(in_min);
+
     if (out_min == NULL) {
         return NULL;
     }
 
     out_max = _ped_Geometry2PedGeometry(in_max);
+
     if (out_max == NULL) {
         return NULL;
     }
@@ -324,20 +306,20 @@ PyObject *py_ped_constraint_new_from_min_max(PyObject *s, PyObject *args) {
     }
 
     constraint = ped_constraint_new_from_min_max(out_min, out_max);
+
     if (constraint) {
         ret = PedConstraint2_ped_Constraint(constraint);
-    }
-    else {
+    } else {
         PyErr_SetString(CreateException, "Could not create new constraint from min/max");
         return NULL;
     }
 
     ped_constraint_destroy(constraint);
-
     return (PyObject *) ret;
 }
 
-PyObject *py_ped_constraint_new_from_min(PyObject *s, PyObject *args) {
+PyObject *py_ped_constraint_new_from_min(PyObject *s, PyObject *args)
+{
     PyObject *in_min = NULL;
     PedGeometry *out_min = NULL;
     PedConstraint *constraint = NULL;
@@ -348,25 +330,26 @@ PyObject *py_ped_constraint_new_from_min(PyObject *s, PyObject *args) {
     }
 
     out_min = _ped_Geometry2PedGeometry(in_min);
+
     if (out_min == NULL) {
         return NULL;
     }
 
     constraint = ped_constraint_new_from_min(out_min);
+
     if (constraint) {
         ret = PedConstraint2_ped_Constraint(constraint);
-    }
-    else {
+    } else {
         PyErr_SetString(CreateException, "Could not create new constraint from min");
         return NULL;
     }
 
     ped_constraint_destroy(constraint);
-
     return (PyObject *) ret;
 }
 
-PyObject *py_ped_constraint_new_from_max(PyObject *s, PyObject *args) {
+PyObject *py_ped_constraint_new_from_max(PyObject *s, PyObject *args)
+{
     PyObject *in_max = NULL;
     PedGeometry *out_max = NULL;
     PedConstraint *constraint = NULL;
@@ -377,39 +360,32 @@ PyObject *py_ped_constraint_new_from_max(PyObject *s, PyObject *args) {
     }
 
     out_max = _ped_Geometry2PedGeometry(in_max);
+
     if (out_max == NULL) {
         return NULL;
     }
 
     constraint = ped_constraint_new_from_max(out_max);
+
     if (constraint) {
         ret = PedConstraint2_ped_Constraint(constraint);
-    }
-    else {
+    } else {
         PyErr_SetString(CreateException, "Could not create new constraint from max");
         return NULL;
     }
 
     ped_constraint_destroy(constraint);
-
     return (PyObject *) ret;
 }
 
-/* XXX: Remove this function at some point in the future.  The deprecation
- * warning tells people what they should be doing.
- */
-PyObject *py_ped_constraint_duplicate(PyObject *s, PyObject *args) {
+PyObject *py_ped_constraint_duplicate(PyObject *s, PyObject *args)
+{
     PedConstraint *constraint = NULL, *dup_constraint = NULL;
     _ped_Constraint *ret = NULL;
 
     constraint = _ped_Constraint2PedConstraint(s);
-    if (constraint == NULL) {
-        return NULL;
-    }
 
-    if (PyErr_WarnEx(PyExc_DeprecationWarning,
-                     "use copy.deepcopy() to duplicate a _ped.Constraint",
-                     1) == -1) {
+    if (constraint == NULL) {
         return NULL;
     }
 
@@ -424,77 +400,75 @@ PyObject *py_ped_constraint_duplicate(PyObject *s, PyObject *args) {
     }
 
     ped_constraint_destroy(dup_constraint);
-
     return (PyObject *) ret;
 }
 
-PyObject *py_ped_constraint_intersect(PyObject *s, PyObject *args) {
+PyObject *py_ped_constraint_intersect(PyObject *s, PyObject *args)
+{
     PyObject *in_constraintB = NULL;
     PedConstraint *constraintA = NULL, *constraintB = NULL;
     PedConstraint *constraint = NULL;
     _ped_Constraint *ret = NULL;
 
-    if (!PyArg_ParseTuple(args, "O!", &_ped_Constraint_Type_obj,
-                          &in_constraintB)) {
+    if (!PyArg_ParseTuple(args, "O!", &_ped_Constraint_Type_obj, &in_constraintB)) {
         return NULL;
     }
 
     constraintA = _ped_Constraint2PedConstraint(s);
+
     if (constraintA == NULL) {
         return NULL;
     }
 
     constraintB = _ped_Constraint2PedConstraint(in_constraintB);
+
     if (constraintB == NULL) {
         ped_constraint_destroy(constraintA);
         return NULL;
     }
 
     constraint = ped_constraint_intersect(constraintA, constraintB);
-
     ped_constraint_destroy(constraintA);
     ped_constraint_destroy(constraintB);
 
     if (constraint) {
         ret = PedConstraint2_ped_Constraint(constraint);
-    }
-    else {
+    } else {
         PyErr_SetString(PyExc_ArithmeticError, "Could not find constraint intersection");
         return NULL;
     }
 
     ped_constraint_destroy(constraint);
-
     return (PyObject *) ret;
 }
 
-PyObject *py_ped_constraint_solve_max(PyObject *s, PyObject *args) {
+PyObject *py_ped_constraint_solve_max(PyObject *s, PyObject *args)
+{
     PedConstraint *constraint = NULL;
     PedGeometry *geometry = NULL;
     _ped_Geometry *ret = NULL;
 
     constraint = _ped_Constraint2PedConstraint(s);
+
     if (constraint == NULL) {
         return NULL;
     }
 
     geometry = ped_constraint_solve_max(constraint);
-
     ped_constraint_destroy(constraint);
 
     if (geometry) {
         ret = PedGeometry2_ped_Geometry(geometry);
-    }
-    else {
+    } else {
         if (partedExnRaised) {
             partedExnRaised = 0;
 
-            if (!PyErr_ExceptionMatches(PartedException) &&
-                !PyErr_ExceptionMatches(PyExc_NotImplementedError))
+            if (!PyErr_ExceptionMatches(PartedException) && !PyErr_ExceptionMatches(PyExc_NotImplementedError)) {
                 PyErr_SetString(ConstraintException, partedExnMessage);
-        }
-        else
+            }
+        } else {
             PyErr_SetString(PyExc_ArithmeticError, "Could not find largest region satisfying constraint");
+        }
 
         return NULL;
     }
@@ -502,37 +476,37 @@ PyObject *py_ped_constraint_solve_max(PyObject *s, PyObject *args) {
     return (PyObject *) ret;
 }
 
-PyObject *py_ped_constraint_solve_nearest(PyObject *s, PyObject *args) {
+PyObject *py_ped_constraint_solve_nearest(PyObject *s, PyObject *args)
+{
     PyObject *in_geometry = NULL;
     PedConstraint *constraint = NULL;
     PedGeometry *out_geometry = NULL;
     PedGeometry *geometry = NULL;
     _ped_Geometry *ret = NULL;
 
-    if (!PyArg_ParseTuple(args, "O!", &_ped_Geometry_Type_obj,
-                          &in_geometry)) {
+    if (!PyArg_ParseTuple(args, "O!", &_ped_Geometry_Type_obj, &in_geometry)) {
         return NULL;
     }
 
     constraint = _ped_Constraint2PedConstraint(s);
+
     if (constraint == NULL) {
         return NULL;
     }
 
     out_geometry = _ped_Geometry2PedGeometry(in_geometry);
+
     if (out_geometry == NULL) {
         ped_constraint_destroy(constraint);
         return NULL;
     }
 
     geometry = ped_constraint_solve_nearest(constraint, out_geometry);
-
     ped_constraint_destroy(constraint);
 
     if (geometry) {
         ret = PedGeometry2_ped_Geometry(geometry);
-    }
-    else {
+    } else {
         PyErr_SetString(PyExc_ArithmeticError, "Could not find region nearest to constraint for given geometry");
         return NULL;
     }
@@ -540,23 +514,25 @@ PyObject *py_ped_constraint_solve_nearest(PyObject *s, PyObject *args) {
     return (PyObject *) ret;
 }
 
-PyObject *py_ped_constraint_is_solution(PyObject *s, PyObject *args) {
+PyObject *py_ped_constraint_is_solution(PyObject *s, PyObject *args)
+{
     PyObject *in_geometry = NULL;
     PedConstraint *constraint = NULL;
     PedGeometry *out_geometry = NULL;
     int ret = 0;
 
-    if (!PyArg_ParseTuple(args, "O!", &_ped_Geometry_Type_obj,
-                          &in_geometry)) {
+    if (!PyArg_ParseTuple(args, "O!", &_ped_Geometry_Type_obj, &in_geometry)) {
         return NULL;
     }
 
     constraint = _ped_Constraint2PedConstraint(s);
+
     if (constraint == NULL) {
         return NULL;
     }
 
     out_geometry = _ped_Geometry2PedGeometry(in_geometry);
+
     if (out_geometry == NULL) {
         ped_constraint_destroy(constraint);
         return NULL;
@@ -572,7 +548,8 @@ PyObject *py_ped_constraint_is_solution(PyObject *s, PyObject *args) {
     }
 }
 
-PyObject *py_ped_constraint_any(PyObject *s, PyObject *args) {
+PyObject *py_ped_constraint_any(PyObject *s, PyObject *args)
+{
     PyObject *in_device = NULL;
     PedDevice *out_device = NULL;
     PedConstraint *constraint = NULL;
@@ -583,25 +560,26 @@ PyObject *py_ped_constraint_any(PyObject *s, PyObject *args) {
     }
 
     out_device = _ped_Device2PedDevice(in_device);
+
     if (out_device == NULL) {
         return NULL;
     }
 
     constraint = ped_constraint_any(out_device);
+
     if (constraint) {
         ret = PedConstraint2_ped_Constraint(constraint);
-    }
-    else {
+    } else {
         PyErr_SetString(CreateException, "Could not create new constraint");
         return NULL;
     }
 
     ped_constraint_destroy(constraint);
-
     return (PyObject *) ret;
 }
 
-PyObject *py_ped_constraint_exact(PyObject *s, PyObject *args) {
+PyObject *py_ped_constraint_exact(PyObject *s, PyObject *args)
+{
     PyObject *in_geometry = NULL;
     PedGeometry *out_geometry = NULL;
     PedConstraint *constraint = NULL;
@@ -612,23 +590,20 @@ PyObject *py_ped_constraint_exact(PyObject *s, PyObject *args) {
     }
 
     out_geometry = _ped_Geometry2PedGeometry(in_geometry);
+
     if (out_geometry == NULL) {
         return NULL;
     }
 
     constraint = ped_constraint_exact(out_geometry);
+
     if (constraint) {
         ret = PedConstraint2_ped_Constraint(constraint);
-    }
-    else {
+    } else {
         PyErr_SetString(CreateException, "Could not create exact constraint");
         return NULL;
     }
 
     ped_constraint_destroy(constraint);
-
     return (PyObject *) ret;
 }
-
-/* vim:tw=78:ts=4:et:sw=4
- */
