@@ -1,22 +1,6 @@
 #
-# Copyright (C) 2008-2011  Red Hat, Inc.
-#
-# This copyrighted material is made available to anyone wishing to use,
-# modify, copy, or redistribute it subject to the terms and conditions of
-# the GNU General Public License v.2, or (at your option) any later version.
-# This program is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY expressed or implied, including the implied warranties of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
-# Public License for more details.  You should have received a copy of the
-# GNU General Public License along with this program; if not, write to the
-# Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-# 02110-1301, USA.  Any Red Hat trademarks that are incorporated in the
-# source code or documentation are not subject to the GNU General Public
-# License and may only be used or replicated with the express permission of
-# Red Hat, Inc.
-#
-# Red Hat Author(s): Chris Lumens <clumens@redhat.com>
-#                    David Cantrell <dcantrell@redhat.com>
+# Copyright The pyparted Project Authors
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
 
 import _ped
@@ -35,8 +19,10 @@ class AlignmentNewTestCase(unittest.TestCase):
         self.assertIsInstance(_ped.Alignment(0, 100), _ped.Alignment)
         self.assertIsInstance(_ped.Alignment(offset=0, grain_size=100), _ped.Alignment)
 
+
 class AlignmentGetSetTestCase(unittest.TestCase):
     def setUp(self):
+        super().setUp()
         self.a = _ped.Alignment(27, 49)
 
     def runTest(self):
@@ -65,8 +51,10 @@ class AlignmentGetSetTestCase(unittest.TestCase):
         # Check that looking for invalid attributes fails properly.
         self.assertRaises(AttributeError, getattr, self.a, "blah")
 
+
 class AlignmentDuplicateTestCase(unittest.TestCase):
     def setUp(self):
+        super().setUp()
         self.a = _ped.Alignment(27, 49)
         self.dup = self.a.duplicate()
 
@@ -74,8 +62,10 @@ class AlignmentDuplicateTestCase(unittest.TestCase):
         self.assertEqual(self.a.offset, self.dup.offset)
         self.assertEqual(self.a.grain_size, self.dup.grain_size)
 
+
 class AlignmentIntersectTestCase(unittest.TestCase):
     def setUp(self):
+        super().setUp()
         self.trivialA = _ped.Alignment(47, 0)
         self.trivialB = _ped.Alignment(47, 0)
 
@@ -113,8 +103,7 @@ class AlignmentIntersectTestCase(unittest.TestCase):
         # complex test second, see libparted/cs/natmath.c for an explanation
         # of the math behind computing the intersection of two alignments
         (verifyA, verifyB) = self.orderAlignments(self.complexA, self.complexB)
-        (gcd, x, _y) = self.extendedEuclid(verifyA.grain_size,
-                                           verifyB.grain_size)
+        (gcd, x, _y) = self.extendedEuclid(verifyA.grain_size, verifyB.grain_size)
         delta_on_gcd = (verifyB.offset - verifyA.offset) / gcd
         new_offset = verifyA.offset + x * delta_on_gcd * verifyA.grain_size
         new_grain_size = verifyA.grain_size * verifyB.grain_size / gcd
@@ -123,9 +112,10 @@ class AlignmentIntersectTestCase(unittest.TestCase):
         self.assertEqual(new_offset, intersection.offset)
         self.assertEqual(new_grain_size, intersection.grain_size)
 
+
 class AlignmentAlignUpTestCase(RequiresDeviceAlignment):
     def setUp(self):
-        RequiresDeviceAlignment.setUp(self)
+        super().setUp()
         self.trivialA = _ped.Alignment(10, 0)
         self.complexA = _ped.Alignment(512, 34)
         self.geometry = _ped.Geometry(self._device, start=0, length=100)
@@ -133,21 +123,25 @@ class AlignmentAlignUpTestCase(RequiresDeviceAlignment):
 
     def runTest(self):
         # trivial test case first, grain_size is zero
-        expected = self.closestInsideGeometry(self.trivialA, self.geometry,
-                                              self.trivialA.offset)
+        expected = self.closestInsideGeometry(
+            self.trivialA, self.geometry, self.trivialA.offset
+        )
         result = self.trivialA.align_up(self.geometry, self.sector)
         self.assertEqual(result, expected)
 
         # complex test case second, grain_size is not zero
-        tmp = self.roundUpTo(self.sector - self.complexA.offset,
-                             self.complexA.grain_size) + self.complexA.offset
+        tmp = (
+            self.roundUpTo(self.sector - self.complexA.offset, self.complexA.grain_size)
+            + self.complexA.offset
+        )
         expected = self.closestInsideGeometry(self.complexA, self.geometry, tmp)
         result = self.complexA.align_up(self.geometry, self.sector)
         self.assertEqual(result, expected)
 
+
 class AlignmentAlignDownTestCase(RequiresDeviceAlignment):
     def setUp(self):
-        RequiresDeviceAlignment.setUp(self)
+        super().setUp()
         self.trivialA = _ped.Alignment(10, 0)
         self.complexA = _ped.Alignment(512, 34)
         self.geometry = _ped.Geometry(self._device, start=0, length=100)
@@ -155,21 +149,27 @@ class AlignmentAlignDownTestCase(RequiresDeviceAlignment):
 
     def runTest(self):
         # trivial test case first, grain_size is zero
-        expected = self.closestInsideGeometry(self.trivialA, self.geometry,
-                                              self.trivialA.offset)
+        expected = self.closestInsideGeometry(
+            self.trivialA, self.geometry, self.trivialA.offset
+        )
         result = self.trivialA.align_down(self.geometry, self.sector)
         self.assertEqual(result, expected)
 
         # complex test case second, grain_size is not zero
-        tmp = self.roundDownTo(self.sector - self.complexA.offset,
-                               self.complexA.grain_size) + self.complexA.offset
+        tmp = (
+            self.roundDownTo(
+                self.sector - self.complexA.offset, self.complexA.grain_size
+            )
+            + self.complexA.offset
+        )
         expected = self.closestInsideGeometry(self.complexA, self.geometry, tmp)
         result = self.complexA.align_down(self.geometry, self.sector)
         self.assertEqual(result, expected)
 
+
 class AlignmentAlignNearestTestCase(RequiresDeviceAlignment):
     def setUp(self):
-        RequiresDeviceAlignment.setUp(self)
+        super().setUp()
         self.trivialA = _ped.Alignment(10, 0)
         self.complexA = _ped.Alignment(512, 34)
         self.geometry = _ped.Geometry(self._device, start=0, length=100)
@@ -177,28 +177,36 @@ class AlignmentAlignNearestTestCase(RequiresDeviceAlignment):
 
     def runTest(self):
         # trivial test case first, grain_size is zero
-        tmp = self.closestInsideGeometry(self.trivialA, self.geometry,
-                                         self.trivialA.offset)
+        tmp = self.closestInsideGeometry(
+            self.trivialA, self.geometry, self.trivialA.offset
+        )
         expected = self.closest(self.sector, tmp, tmp)
         result = self.trivialA.align_nearest(self.geometry, self.sector)
         self.assertEqual(result, expected)
 
         # complex test case second, grain_size is not zero
-        tmpA = self.roundUpTo(self.sector - self.complexA.offset,
-                              self.complexA.grain_size) + self.complexA.offset
+        tmpA = (
+            self.roundUpTo(self.sector - self.complexA.offset, self.complexA.grain_size)
+            + self.complexA.offset
+        )
         tmpA = self.closestInsideGeometry(self.complexA, self.geometry, tmpA)
 
-        tmpB = self.roundDownTo(self.sector - self.complexA.offset,
-                                self.complexA.grain_size) + self.complexA.offset
+        tmpB = (
+            self.roundDownTo(
+                self.sector - self.complexA.offset, self.complexA.grain_size
+            )
+            + self.complexA.offset
+        )
         tmpB = self.closestInsideGeometry(self.complexA, self.geometry, tmpB)
 
         expected = self.closest(self.sector, tmpA, tmpB)
         result = self.complexA.align_nearest(self.geometry, self.sector)
         self.assertEqual(result, expected)
 
+
 class AlignmentIsAlignedTestCase(RequiresDevice):
     def setUp(self):
-        RequiresDevice.setUp(self)
+        super().setUp()
         self.g = _ped.Geometry(self._device, start=0, length=100)
         self.a = _ped.Alignment(10, 0)
 
@@ -220,8 +228,10 @@ class AlignmentIsAlignedTestCase(RequiresDevice):
         self.assertTrue(self.a.is_aligned(self.g, 20))
         self.assertFalse(self.a.is_aligned(self.g, 23))
 
+
 class AlignmentStrTestCase(unittest.TestCase):
     def setUp(self):
+        super().setUp()
         self.alignment = _ped.Alignment(10, 0)
 
     def runTest(self):
