@@ -1,22 +1,6 @@
 #
-# Copyright (C) 2008-2011  Red Hat, Inc.
-#
-# This copyrighted material is made available to anyone wishing to use,
-# modify, copy, or redistribute it subject to the terms and conditions of
-# the GNU General Public License v.2, or (at your option) any later version.
-# This program is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY expressed or implied, including the implied warranties of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
-# Public License for more details.  You should have received a copy of the
-# GNU General Public License along with this program; if not, write to the
-# Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-# 02110-1301, USA.  Any Red Hat trademarks that are incorporated in the
-# source code or documentation are not subject to the GNU General Public
-# License and may only be used or replicated with the express permission of
-# Red Hat, Inc.
-#
-# Red Hat Author(s): Chris Lumens <clumens@redhat.com>
-#                    David Cantrell <dcantrell@redhat.com>
+# Copyright The pyparted Project Authors
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
 
 import _ped
@@ -32,6 +16,7 @@ class CHSGeometryNewTestCase(unittest.TestCase):
         # You're not allowed to create a new CHSGeometry object by hand.
         self.assertRaises(TypeError, _ped.CHSGeometry)
 
+
 class CHSGeometryGetSetTestCase(RequiresDevice):
     def runTest(self):
         # A device has a CHSGeometry, so we can use that to attempt accessing
@@ -48,8 +33,16 @@ class CHSGeometryGetSetTestCase(RequiresDevice):
         self.assertIsInstance(chs.heads, int)
         self.assertIsInstance(chs.sectors, int)
 
+
 class CHSGeometryStrTestCase(RequiresDevice):
     def runTest(self):
-        expected = "_ped.CHSGeometry instance --\n  cylinders: %d  heads: %d  sectors: %d" % (self._device.hw_geom.cylinders, self._device.hw_geom.heads, self._device.hw_geom.sectors,)
+        expected = (
+            "_ped.CHSGeometry instance --\n  cylinders: %d  heads: %d  sectors: %d"
+            % (
+                self._device.hw_geom.cylinders,
+                self._device.hw_geom.heads,
+                self._device.hw_geom.sectors,
+            )
+        )
         result = str(self._device.hw_geom)
         self.assertEqual(result, expected)
