@@ -1,25 +1,9 @@
 #
-# Copyright (C) 2008-2016  Red Hat, Inc.
-#
-# This copyrighted material is made available to anyone wishing to use,
-# modify, copy, or redistribute it subject to the terms and conditions of
-# the GNU General Public License v.2, or (at your option) any later version.
-# This program is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY expressed or implied, including the implied warranties of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
-# Public License for more details.  You should have received a copy of the
-# GNU General Public License along with this program; if not, write to the
-# Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-# 02110-1301, USA.  Any Red Hat trademarks that are incorporated in the
-# source code or documentation are not subject to the GNU General Public
-# License and may only be used or replicated with the express permission of
-# Red Hat, Inc.
-#
-# Red Hat Author(s): Chris Lumens <clumens@redhat.com>
+# Copyright The pyparted Project Authors
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
 
 import _ped
-import six
 from tests.baseclass import RequiresDevice
 
 # One class per method, multiple tests per class.  For these simple methods,
@@ -37,9 +21,10 @@ class GeometryNewTestCase(RequiresDevice):
         self.assertIsInstance(_ped.Geometry(self._device, 0, 100), _ped.Geometry)
         self.assertIsInstance(_ped.Geometry(self._device, 0, 100, 101), _ped.Geometry)
 
+
 class GeometryGetSetTestCase(RequiresDevice):
     def setUp(self):
-        RequiresDevice.setUp(self)
+        super().setUp()
         self.g = _ped.Geometry(self._device, start=0, length=100)
 
     def runTest(self):
@@ -73,9 +58,10 @@ class GeometryGetSetTestCase(RequiresDevice):
         # Check that looking for invalid attributes fails properly.
         self.assertRaises(AttributeError, getattr, self.g, "blah")
 
+
 class GeometryDuplicateTestCase(RequiresDevice):
     def setUp(self):
-        RequiresDevice.setUp(self)
+        super().setUp()
         self.g = _ped.Geometry(self._device, start=0, length=100)
         self.dup = self.g.duplicate()
 
@@ -84,9 +70,10 @@ class GeometryDuplicateTestCase(RequiresDevice):
         self.assertEqual(self.g.length, self.dup.length)
         self.assertEqual(self.g.end, self.dup.end)
 
+
 class GeometryIntersectTestCase(RequiresDevice):
     def setUp(self):
-        RequiresDevice.setUp(self)
+        super().setUp()
         self.g1 = _ped.Geometry(self._device, start=0, length=100)
         self.g2 = _ped.Geometry(self._device, start=0, length=100)
         self.i = None
@@ -118,9 +105,10 @@ class GeometryIntersectTestCase(RequiresDevice):
         self.g2.set(50, 100)
         self.assertRaises(ArithmeticError, self.g1.intersect, self.g2)
 
+
 class GeometrySetTestCase(RequiresDevice):
     def setUp(self):
-        RequiresDevice.setUp(self)
+        super().setUp()
         self.g = _ped.Geometry(self._device, start=0, length=100)
 
     def runTest(self):
@@ -131,9 +119,10 @@ class GeometrySetTestCase(RequiresDevice):
         # the device should fail.
         self.assertRaises(_ped.CreateException, self.g.set, 100, -1000)
 
+
 class GeometrySetStartTestCase(RequiresDevice):
     def setUp(self):
-        RequiresDevice.setUp(self)
+        super().setUp()
         self.g = _ped.Geometry(self._device, start=0, length=100)
 
     def runTest(self):
@@ -142,9 +131,10 @@ class GeometrySetStartTestCase(RequiresDevice):
         self.assertEqual(self.g.length, 90)
         self.assertEqual(self.g.end, 99)
 
+
 class GeometrySetEndTestCase(RequiresDevice):
     def setUp(self):
-        RequiresDevice.setUp(self)
+        super().setUp()
         self.g = _ped.Geometry(self._device, start=0, length=100)
 
     def runTest(self):
@@ -158,9 +148,10 @@ class GeometrySetEndTestCase(RequiresDevice):
         self.g.set_start(10)
         self.assertRaises(_ped.CreateException, self.g.set_end, 5)
 
+
 class GeometryTestOverlapTestCase(RequiresDevice):
     def setUp(self):
-        RequiresDevice.setUp(self)
+        super().setUp()
         self.g1 = _ped.Geometry(self._device, start=0, length=100)
         self.g2 = _ped.Geometry(self._device, start=50, length=100)
 
@@ -180,9 +171,10 @@ class GeometryTestOverlapTestCase(RequiresDevice):
         self.g2.set(10, 10)
         self.assertFalse(self.g1.test_overlap(self.g2))
 
+
 class GeometryTestInsideTestCase(RequiresDevice):
     def setUp(self):
-        RequiresDevice.setUp(self)
+        super().setUp()
         self.g1 = _ped.Geometry(self._device, start=0, length=100)
         self.g2 = _ped.Geometry(self._device, start=0, length=100)
 
@@ -206,9 +198,10 @@ class GeometryTestInsideTestCase(RequiresDevice):
         self.assertFalse(self.g1.test_inside(self.g2))
         self.assertFalse(self.g2.test_inside(self.g1))
 
+
 class GeometryTestEqualTestCase(RequiresDevice):
     def setUp(self):
-        RequiresDevice.setUp(self)
+        super().setUp()
         self.g1 = _ped.Geometry(self._device, start=0, length=100)
         self.g2 = _ped.Geometry(self._device, start=0, length=100)
 
@@ -225,9 +218,10 @@ class GeometryTestEqualTestCase(RequiresDevice):
         self.g2.set_end(50)
         self.assertFalse(self.g1.test_equal(self.g2))
 
+
 class GeometryTestSectorInsideTestCase(RequiresDevice):
     def setUp(self):
-        RequiresDevice.setUp(self)
+        super().setUp()
         self.g = _ped.Geometry(self._device, start=10, length=100)
 
     def runTest(self):
@@ -241,9 +235,10 @@ class GeometryTestSectorInsideTestCase(RequiresDevice):
         self.assertFalse(self.g.test_sector_inside(1000))
         self.assertFalse(self.g.test_sector_inside(-1))
 
+
 class GeometryReadTestCase(RequiresDevice):
     def setUp(self):
-        RequiresDevice.setUp(self)
+        super().setUp()
         self.g = _ped.Geometry(self._device, start=10, length=100)
 
     def runTest(self):
@@ -277,9 +272,10 @@ class GeometryReadTestCase(RequiresDevice):
 
         self._device.close()
 
+
 class GeometrySyncTestCase(RequiresDevice):
     def setUp(self):
-        RequiresDevice.setUp(self)
+        super().setUp()
         self.g = _ped.Geometry(self._device, start=0, length=100)
 
     def runTest(self):
@@ -291,9 +287,10 @@ class GeometrySyncTestCase(RequiresDevice):
 
         self._device.close()
 
+
 class GeometrySyncFastTestCase(RequiresDevice):
     def setUp(self):
-        RequiresDevice.setUp(self)
+        super().setUp()
         self.g = _ped.Geometry(self._device, start=0, length=100)
 
     def runTest(self):
@@ -305,9 +302,10 @@ class GeometrySyncFastTestCase(RequiresDevice):
 
         self._device.close()
 
+
 class GeometryWriteTestCase(RequiresDevice):
     def setUp(self):
-        RequiresDevice.setUp(self)
+        super().setUp()
         self.g = _ped.Geometry(self._device, start=10, length=100)
 
     def runTest(self):
@@ -333,9 +331,10 @@ class GeometryWriteTestCase(RequiresDevice):
 
         self._device.close()
 
+
 class GeometryCheckTestCase(RequiresDevice):
     def setUp(self):
-        RequiresDevice.setUp(self)
+        super().setUp()
         self.g = _ped.Geometry(self._device, start=10, length=100)
 
     def runTest(self):
@@ -349,9 +348,10 @@ class GeometryCheckTestCase(RequiresDevice):
 
         self._device.close()
 
+
 class GeometryMapTestCase(RequiresDevice):
     def setUp(self):
-        RequiresDevice.setUp(self)
+        super().setUp()
         self.g1 = _ped.Geometry(self._device, start=10, length=100)
         self.g2 = _ped.Geometry(self._device, start=10, length=90)
 
@@ -366,13 +366,14 @@ class GeometryMapTestCase(RequiresDevice):
 
         self._device.close()
 
+
 class GeometryStrTestCase(RequiresDevice):
     def setUp(self):
-        RequiresDevice.setUp(self)
+        super().setUp()
         self.g = _ped.Geometry(self._device, start=10, length=100)
 
     def runTest(self):
-        lines = str(self.g).split('\n')
-        self.assertEqual(lines[0], '_ped.Geometry instance --')
-        self.assertEqual(lines[1], '  start: 10  end: 109  length: 100')
-        six.assertRegex(self, lines[2], '^  device: <_ped.Device object at .*')
+        lines = str(self.g).split("\n")
+        self.assertEqual(lines[0], "_ped.Geometry instance --")
+        self.assertEqual(lines[1], "  start: 10  end: 109  length: 100")
+        self.assertRegex(lines[2], "^  device: <_ped.Device object at .*")
